Welcome to bepasty's documentation!
===================================

bepasty is like a pastebin for every kind of file (text, image, audio, video, documents, ...).

You can upload multiple files at once, simply by drag and drop.

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   config
   install-tutorial
